#include "calculatorwidget.h"
#include "ui_calculatorwidget.h"

#include <QMessageBox>

CalculatorWidget::CalculatorWidget(QWidget *parent) :
    QWidget(parent),
    _ui(new Ui::CalculatorWidget)
{
    _ui->setupUi(this); // grafikus felület összeállítása
    setFixedSize(172,250); // méret rögzítése

    _currentOperation = NONE; // kezdetben nincs művelet
    _firstNumber = _secondNumber = 0;

    connect(_ui->addButton,SIGNAL(clicked()), this, SLOT(add()));
    connect(_ui->subButton,SIGNAL(clicked()), this, SLOT(substract()));
    connect(_ui->multiplyButton,SIGNAL(clicked()), this, SLOT(multiply()));
    connect(_ui->divideButton,SIGNAL(clicked()), this, SLOT(divide()));
    connect(_ui->equalButton,SIGNAL(clicked()), this, SLOT(equal()));

    _ui->numberLineEdit->setFocus(); // a szövegmezőre állítjuk a fókuszt
    _ui->numberLineEdit->selectAll(); // az összes szöveg kijelölése
}

CalculatorWidget::~CalculatorWidget()
{
    delete _ui;
}

void CalculatorWidget::add()
{
    operate(ADD);
}

void CalculatorWidget::substract()
{
    operate(SUBSTRACT);
}

void CalculatorWidget::multiply()
{
    operate(MULTIPLY);
}

void CalculatorWidget::divide()
{
    operate(DIVIDE);
}

void CalculatorWidget::equal()
{
    operate(NONE);
}

void CalculatorWidget::operate(Operation nextOperation)
{
    bool isNumber;
    _secondNumber = _ui->numberLineEdit->text().toFloat(&isNumber);
        // beolvassuk a második operandust, és ellenőrizzük a tartalmat
    if (!isNumber) // ha nem számot adtunk meg, hibát jelzünk
    {
        QMessageBox::critical(this, tr("Hiba!"), trUtf8("Nem számot adtál meg!"));
        return;
    }

    if (_currentOperation != NONE) // ha már van művelet kiadva
    {
        float result;

        switch (_currentOperation) // végrehajtjuk a korábbi mûveletet a két operandussal
        {
            case ADD: result = _firstNumber + _secondNumber; break;
            case SUBSTRACT: result = _firstNumber - _secondNumber; break;
            case MULTIPLY: result = _firstNumber * _secondNumber; break;
            case DIVIDE: result = _firstNumber / _secondNumber; break;
        }

        _secondNumber = result;
        _ui->numberLineEdit->setText(QString::number(result)); // az eredményt a kéápernyőre írjuk
    }

    _firstNumber = _secondNumber; // eltároljuk az első operandust
    _currentOperation = nextOperation; // eltároljuk a következő műveletet

    _ui->numberLineEdit->setFocus(); // a szövegmezőre állítjuk a fókuszt
    _ui->numberLineEdit->selectAll(); // az összes szöveg kijelölése
}
